package Bundle::Math::Financial;
use strict;
use warnings;

$VERSION = '1.00';

1;

__END__

=head1 NAME

Bundle::Math::Financial - Bundle of modules related to financial mathematics

=head1 SYNOPSIS

 perl -MCPAN -e 'install Bundle::Math::Financial'

=head1 CONTENTS

Math::Business::BlackScholes

Math::Business::EMA

Math::Business::MACD

Math::Business::SMA

Math::Calc::Euro

Math::Currency

Math::Financial

=head1 DESCRIPTION

This is a bundle of modules related to financial mathematics.

Please have a look at L<Bundle::Math>.

If you would like to see a specific module included in a future version of
this bundle, please send me an email or use rt.cpan.org.

=head1 AUTHOR

Steffen Mueller E<lt>bundlemath-module at steffen-mueller dot netE<gt>

=cut 
